package Meurs
  connector bfc
    Real p(unit = "torr");
    flow Real q(unit = "ml/s");
    annotation(Icon(graphics = {Rectangle(origin = {-1, 0}, extent = {{-97, 98}, {97, -98}})}));
  end bfc;

  connector bfc_in
    extends Meurs.bfc;
    annotation(Icon(graphics = {Rectangle(origin = {0, -1}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-98, 99}, {98, -99}})}));
  end bfc_in;

  connector bfc_out
    extends Meurs.bfc;
    annotation(Icon(graphics = {Rectangle(origin = {-1, 0}, fillColor = {141, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-99, 100}, {99, -100}})}));
  end bfc_out;

  model OnePort
    bfc_in In annotation(Placement(visible = true, transformation(origin = {-84, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out Out annotation(Placement(visible = true, transformation(origin = {88, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Real q = In.q;
    Real dp = In.p - Out.p;
  equation
    In.q + Out.q = 0;
    annotation(Icon(graphics = {Rectangle(origin = {1, 0}, extent = {{-89, 82}, {89, -82}})}));
  end OnePort;

  model Resistor
    extends Meurs.OnePort;
    parameter Real R;
  equation
    dp = R*q;
  annotation(Icon(graphics = {Rectangle(origin = {1, -1}, fillColor = {243, 16, 16}, fillPattern = FillPattern.Backward, extent = {{-85, 77}, {85, -77}})}));end Resistor;

  model ResistorVariable
    extends Meurs.OnePort;
    Modelica.Blocks.Interfaces.RealInput R annotation(Placement(visible = true, transformation(origin = {-84, 74}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-80, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    equation
    dp = R*q;
  annotation(Icon(graphics = {Rectangle(origin = {0, -2}, fillColor = {229, 20, 20}, fillPattern = FillPattern.CrossDiag, extent = {{-82, 70}, {82, -70}})}));end ResistorVariable;

  model Inertance
    extends Meurs.OnePort;
    Modelica.Blocks.Interfaces.RealInput L annotation(Placement(visible = true, transformation(origin = {-78, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-78, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    equation
    dp = der(q)*L;
  end Inertance;

  model ElasticCompartment
   bfc_in In annotation(Placement(visible = true, transformation(origin = {0, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealInput ExternalPressure annotation(Placement(visible = true, transformation(origin = {-8, 64}, extent = {{-32, -32}, {32, 32}}, rotation = 0), iconTransformation(origin = {4, 76}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealInput Elastance annotation(Placement(visible = true, transformation(origin = {-84, 66}, extent = {{-32, -32}, {32, 32}}, rotation = 0), iconTransformation(origin = {-72, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealOutput Volume(start = V0) annotation(Placement(visible = true, transformation(origin = {70, -76}, extent = {{-34, -34}, {34, 34}}, rotation = 0), iconTransformation(origin = {84, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealOutput StressedVolume annotation(Placement(visible = true, transformation(origin = {2, -72}, extent = {{-30, -30}, {30, 30}}, rotation = 0), iconTransformation(origin = {16, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealOutput Pressure annotation(Placement(visible = true, transformation(origin = {-61, -69}, extent = {{-31, -31}, {31, 31}}, rotation = 0), iconTransformation(origin = {-46, -84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Real V0(unit = "ml")
      "initial volume if elastic compartment in ml";
    parameter Real UnstressedVolume(unit = "ml") "unstressed volume in ml";
    Real TransmuralPressure(unit = "mmHg");
  equation
    annotation(Icon(graphics = {Ellipse(origin = {1, 0}, lineColor = {53, 49, 1}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Sphere, extent = {{-97, 98}, {97, -98}}, endAngle = 360)}));
  end ElasticCompartment;
  annotation(uses(Modelica(version = "3.2.2")));
end Meurs;
